==> react-cmp-banner-1.26.0.tgz: package/lib/CmpBanner/index.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import React, { useState, useRef, Suspense } from 'react';
import PropTypes from 'prop-types';
import { useMount } from '@s-ui/react-hooks';
var CONSENT_STATUS_NOT_ACCEPTED = 'NOT_ACCEPTED';

var NO_OP = function NO_OP() {};

var CmpBanner = React.lazy(function () {
  return import('./component');
});
var CmpModal = React.lazy(function () {
  return import('@s-ui/react-cmp-modal');
});
export default function CmpBannerContainer(_ref) {
  var lang = _ref.lang,
      logo = _ref.logo,
      privacyUrl = _ref.privacyUrl,
      getConsentStatus = _ref.getConsentStatus,
      getPurposesAndVendors = _ref.getPurposesAndVendors,
      sendConsents = _ref.sendConsents,
      _ref$onAccept = _ref.onAccept,
      onAccept = _ref$onAccept === void 0 ? NO_OP : _ref$onAccept,
      _ref$onConfigure = _ref.onConfigure,
      onConfigure = _ref$onConfigure === void 0 ? NO_OP : _ref$onConfigure;

  var _useState = useState(false),
      showModal = _useState[0],
      setShowModal = _useState[1];

  var _useState2 = useState(false),
      showNotification = _useState2[0],
      setShowNotification = _useState2[1];

  var containerDOMEl = useRef();

  var _handleAccept =
  /*#__PURE__*/
  function () {
    var _ref2 = _asyncToGenerator(
    /*#__PURE__*/
    _regeneratorRuntime.mark(function _callee() {
      var _ref3, purposeConsents, vendorConsents;

      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.next = 2;
              return getPurposesAndVendors.execute();

            case 2:
              _ref3 = _context.sent;
              purposeConsents = _ref3.purposeConsents;
              vendorConsents = _ref3.vendorConsents;
              _context.next = 7;
              return sendConsents.execute({
                purposeConsents: purposeConsents,
                vendorConsents: vendorConsents
              });

            case 7:
              setShowModal(false);
              setShowNotification(false);

              _removeBodyEvent();

              onAccept();

            case 11:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }));

    return function _handleAccept() {
      return _ref2.apply(this, arguments);
    };
  }();

  var _handleReadMore =
  /*#__PURE__*/
  function () {
    var _ref4 = _asyncToGenerator(
    /*#__PURE__*/
    _regeneratorRuntime.mark(function _callee2() {
      return _regeneratorRuntime.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              setShowModal(true);
              setShowNotification(true);
              onConfigure();

            case 3:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2);
    }));

    return function _handleReadMore() {
      return _ref4.apply(this, arguments);
    };
  }();
  /**
   * This handler is used everytime the user clicks on something in the web
   * in order to assume he's accepting our CMP if he's not trying to configure it and
   * he's just navigating the website
   */


  var _handleClickOnDocument = function _handleClickOnDocument(_ref5) {
    var target = _ref5.target;
    var isClickableElement = target.closest('a') || target.closest('button') || target.closest('input');
    var isNotContainedInBanner = !containerDOMEl.current.contains(target); // if not contained and clickable element, then accept the banner

    isNotContainedInBanner && isClickableElement && _handleAccept();
  };

  var _handleExitModal = function _handleExitModal() {
    setShowModal(false);
  };

  var _removeBodyEvent = function _removeBodyEvent() {
    document.removeEventListener('click', _handleClickOnDocument);
  };

  useMount(function () {
    function initiConsentStatus() {
      return _initiConsentStatus.apply(this, arguments);
    }

    function _initiConsentStatus() {
      _initiConsentStatus = _asyncToGenerator(
      /*#__PURE__*/
      _regeneratorRuntime.mark(function _callee3() {
        var consentStatus, isConsentNotAccepted;
        return _regeneratorRuntime.wrap(function _callee3$(_context3) {
          while (1) {
            switch (_context3.prev = _context3.next) {
              case 0:
                _context3.next = 2;
                return getConsentStatus.execute();

              case 2:
                consentStatus = _context3.sent;
                isConsentNotAccepted = consentStatus === CONSENT_STATUS_NOT_ACCEPTED;
                setShowNotification(isConsentNotAccepted);

                if (isConsentNotAccepted) {
                  // We're assuming, the user accepts our CMP if he keep navigating in our page
                  document.addEventListener('click', _handleClickOnDocument);
                }

              case 6:
              case "end":
                return _context3.stop();
            }
          }
        }, _callee3);
      }));
      return _initiConsentStatus.apply(this, arguments);
    }

    initiConsentStatus();
    return _removeBodyEvent;
  });
  return React.createElement("div", {
    ref: containerDOMEl
  }, showNotification && React.createElement(Suspense, {
    fallback: React.createElement("div", null)
  }, React.createElement(CmpBanner, {
    onAccept: _handleAccept,
    onConfigure: _handleReadMore,
    lang: lang
  })), showModal && React.createElement(Suspense, {
    fallback: React.createElement("div", null)
  }, React.createElement(CmpModal, {
    cmpReady: true,
    lang: lang,
    logo: logo,
    onExit: _handleExitModal,
    privacyUrl: privacyUrl
  })));
}

==> react-cmp-banner-1.27.0.tgz: package/lib/CmpBanner/index.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { lazy, useState, useRef, Suspense } from 'react';
import { useMount } from '@s-ui/react-hooks';
var CONSENT_STATUS_NOT_ACCEPTED = 'NOT_ACCEPTED';

var NO_OP = function NO_OP() {};

var CmpBanner = /*#__PURE__*/lazy(function () {
  return import('./component');
});
var CmpModal = /*#__PURE__*/lazy(function () {
  return import('@s-ui/react-cmp-modal');
});
export default function CmpBannerContainer(_ref) {
  var lang = _ref.lang,
      logo = _ref.logo,
      privacyUrl = _ref.privacyUrl,
      getConsentStatus = _ref.getConsentStatus,
      getPurposesAndVendors = _ref.getPurposesAndVendors,
      sendConsents = _ref.sendConsents,
      _ref$onAccept = _ref.onAccept,
      onAccept = _ref$onAccept === void 0 ? NO_OP : _ref$onAccept,
      _ref$onConfigure = _ref.onConfigure,
      onConfigure = _ref$onConfigure === void 0 ? NO_OP : _ref$onConfigure;

  var _useState = useState(false),
      showModal = _useState[0],
      setShowModal = _useState[1];

  var _useState2 = useState(false),
      showNotification = _useState2[0],
      setShowNotification = _useState2[1];

  var containerDOMEl = useRef();

  var _handleAccept = /*#__PURE__*/function () {
    var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      var _yield$getPurposesAnd, purposeConsents, vendorConsents;

      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.next = 2;
              return getPurposesAndVendors.execute();

            case 2:
              _yield$getPurposesAnd = _context.sent;
              purposeConsents = _yield$getPurposesAnd.purposeConsents;
              vendorConsents = _yield$getPurposesAnd.vendorConsents;
              _context.next = 7;
              return sendConsents.execute({
                purposeConsents: purposeConsents,
                vendorConsents: vendorConsents
              });

            case 7:
              setShowModal(false);
              setShowNotification(false);

              _removeBodyEvent();

              onAccept();

            case 11:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }));

    return function _handleAccept() {
      return _ref2.apply(this, arguments);
    };
  }();

  var _handleReadMore = /*#__PURE__*/function () {
    var _ref3 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
      return _regeneratorRuntime.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              setShowModal(true);
              setShowNotification(true);
              onConfigure();

            case 3:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2);
    }));

    return function _handleReadMore() {
      return _ref3.apply(this, arguments);
    };
  }();
  /**
   * This handler is used everytime the user clicks on something in the web
   * in order to assume he's accepting our CMP if he's not trying to configure it and
   * he's just navigating the website
   */


  var _handleClickOnDocument = function _handleClickOnDocument(_ref4) {
    var target = _ref4.target;
    var isClickableElement = target.closest('a') || target.closest('button') || target.closest('input');
    var isNotContainedInBanner = !containerDOMEl.current.contains(target); // if not contained and clickable element, then accept the banner

    isNotContainedInBanner && isClickableElement && _handleAccept();
  };

  var _handleExitModal = function _handleExitModal() {
    setShowModal(false);
  };

  var _removeBodyEvent = function _removeBodyEvent() {
    document.removeEventListener('click', _handleClickOnDocument);
  };

  useMount(function () {
    function initiConsentStatus() {
      return _initiConsentStatus.apply(this, arguments);
    }

    function _initiConsentStatus() {
      _initiConsentStatus = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
        var consentStatus, isConsentNotAccepted;
        return _regeneratorRuntime.wrap(function _callee3$(_context3) {
          while (1) {
            switch (_context3.prev = _context3.next) {
              case 0:
                _context3.next = 2;
                return getConsentStatus.execute();

              case 2:
                consentStatus = _context3.sent;
                isConsentNotAccepted = consentStatus === CONSENT_STATUS_NOT_ACCEPTED;
                setShowNotification(isConsentNotAccepted);

                if (isConsentNotAccepted) {
                  // We're assuming, the user accepts our CMP if he keep navigating in our page
                  document.addEventListener('click', _handleClickOnDocument);
                }

              case 6:
              case "end":
                return _context3.stop();
            }
          }
        }, _callee3);
      }));
      return _initiConsentStatus.apply(this, arguments);
    }

    initiConsentStatus();
    return _removeBodyEvent;
  });
  return /*#__PURE__*/_jsxs("div", {
    ref: containerDOMEl,
    children: [showNotification && /*#__PURE__*/_jsx(Suspense, {
      fallback: /*#__PURE__*/_jsx("div", {}),
      children: /*#__PURE__*/_jsx(CmpBanner, {
        onAccept: _handleAccept,
        onConfigure: _handleReadMore,
        lang: lang
      })
    }), showModal && /*#__PURE__*/_jsx(Suspense, {
      fallback: /*#__PURE__*/_jsx("div", {}),
      children: /*#__PURE__*/_jsx(CmpModal, {
        cmpReady: true,
        lang: lang,
        logo: logo,
        onExit: _handleExitModal,
        privacyUrl: privacyUrl
      })
    })]
  });
}
